@@ -248,7 +248,7 @@ ergmm.latentcluster <- function(gY, dimSpace=2, p=0, X=NULL, theta0=NULL, ng = 1
     dir <- 1
   else
     dir <- 0
-  n.edges <- gY$gal$mnext-1 
+  n.edges <- network.edgecount(gY)
   heads<-edgelist[,1]  # C indexes starting at 0
   tails<-edgelist[,2]
   
